@@ -4,7 +4,7 @@ Flower - passive agent
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =head1 SYNOPSIS
 
@@ -27,6 +27,11 @@ Version 0.09
 
  Then visit L<https://127.0.0.1:2222> in your browser.
 
+ test urls passive log
+ L<https://127.0.0.1:2222/q/name>
+ L<https://127.0.0.1:2222/q/class>
+
+
 =cut
 
 package Flower;
